Index: kernel/generic/src/synch/waitq.c
===================================================================
--- kernel/generic/src/synch/waitq.c	(revision 5d12283239700d89ca728d73ee46542a36554290)
+++ kernel/generic/src/synch/waitq.c	(revision 34b3ce3115e73f88ee7c7a1388ff78f9e8ca01cf)
@@ -55,5 +55,5 @@
 #include <adt/list.h>
 
-static void waitq_timeouted_sleep(void *data);
+static void waitq_sleep_timed_out(void *data);
 
 /** Initialize wait queue
@@ -82,5 +82,5 @@
  * @param data Pointer to the thread that called waitq_sleep_timeout().
  */
-void waitq_timeouted_sleep(void *data)
+void waitq_sleep_timed_out(void *data)
 {
 	thread_t *t = (thread_t *) data;
@@ -184,7 +184,7 @@
  * and all the *_timeout() functions use it.
  *
- * @param wq Pointer to wait queue.
- * @param usec Timeout in microseconds.
- * @param flags Specify mode of the sleep.
+ * @param wq		Pointer to wait queue.
+ * @param usec		Timeout in microseconds.
+ * @param flags		Specify mode of the sleep.
  *
  * The sleep can be interrupted only if the
@@ -201,20 +201,21 @@
  * call will immediately return, reporting either success or failure.
  *
- * @return One of: ESYNCH_WOULD_BLOCK, ESYNCH_TIMEOUT, ESYNCH_INTERRUPTED,
- * ESYNCH_OK_ATOMIC, ESYNCH_OK_BLOCKED.
- *
- * @li ESYNCH_WOULD_BLOCK means that the sleep failed because at the time of the
- * call there was no pending wakeup.
- *
- * @li ESYNCH_TIMEOUT means that the sleep timed out.
- *
- * @li ESYNCH_INTERRUPTED means that somebody interrupted the sleeping thread.
- *
- * @li ESYNCH_OK_ATOMIC means that the sleep succeeded and that there was
- * a pending wakeup at the time of the call. The caller was not put
- * asleep at all.
+ * @return		Returns one of ESYNCH_WOULD_BLOCK, ESYNCH_TIMEOUT,
+ * 			ESYNCH_INTERRUPTED, ESYNCH_OK_ATOMIC and
+ * 			ESYNCH_OK_BLOCKED.
+ *
+ * @li	ESYNCH_WOULD_BLOCK means that the sleep failed because at the time of
+ *	the call there was no pending wakeup.
+ *
+ * @li	ESYNCH_TIMEOUT means that the sleep timed out.
+ *
+ * @li	ESYNCH_INTERRUPTED means that somebody interrupted the sleeping thread.
+ *
+ * @li	ESYNCH_OK_ATOMIC means that the sleep succeeded and that there was
+ * 	a pending wakeup at the time of the call. The caller was not put
+ * 	asleep at all.
  * 
- * @li ESYNCH_OK_BLOCKED means that the sleep succeeded; the full sleep was 
- * attempted.
+ * @li	ESYNCH_OK_BLOCKED means that the sleep succeeded; the full sleep was 
+ * 	attempted.
  */
 int waitq_sleep_timeout(waitq_t *wq, uint32_t usec, int flags)
@@ -356,5 +357,5 @@
 		THREAD->timeout_pending = true;
 		timeout_register(&THREAD->sleep_timeout, (uint64_t) usec,
-		    waitq_timeouted_sleep, THREAD);
+		    waitq_sleep_timed_out, THREAD);
 	}
 
@@ -432,5 +433,5 @@
 	 * This is not necessary because of mutual exclusion
 	 * (the link belongs to the wait queue), but because
 	 * of synchronization with waitq_timeouted_sleep()
 	 * and thread_interrupt_sleep().
 	 *
@@ -432,5 +433,5 @@
 	 * This is not necessary because of mutual exclusion
 	 * (the link belongs to the wait queue), but because
-	 * of synchronization with waitq_timeouted_sleep()
+	 * of synchronization with waitq_sleep_timed_out()
 	 * and thread_interrupt_sleep().
 	 *
